@@ -348,6 +348,7 @@ create_admin_section (void)
   g_menu_append (menu, distro_help_label, "indicator.distro_help");
   g_free (desktop_help_label);
   g_free (distro_help_label);
+  g_menu_append (menu, _("Report a Bug…"), "indicator.bug");
   return G_MENU_MODEL (menu);
 }
 
@@ -828,6 +829,14 @@ on_distro_help_activated (GSimpleAction  * a      G_GNUC_UNUSED,
   indicator_session_actions_distro_help (get_backend_actions(gself));
 }
 
+static void
+on_bug_activated (GSimpleAction  * a      G_GNUC_UNUSED,
+                   GVariant       * param  G_GNUC_UNUSED,
+                   gpointer         gself)
+{
+  indicator_session_actions_bug (get_backend_actions(gself));
+}
+
 static void
 on_settings_activated (GSimpleAction * a      G_GNUC_UNUSED,
                        GVariant      * param  G_GNUC_UNUSED,
@@ -921,6 +930,7 @@ init_gactions (IndicatorSessionService * self)
     { "about",                  on_about_activated           },
     { "desktop_help",           on_desktop_help_activated    },
     { "distro_help",            on_distro_help_activated     },
+    { "bug",                    on_bug_activated             },
     { "hibernate",              on_hibernate_activated       },
     { "logout",                 on_logout_activated          },
     { "online-accounts",        on_online_accounts_activated },
@@ -1070,7 +1080,7 @@ on_bus_acquired (GDBusConnection * connection,
 
   g_debug ("bus acquired: %s", name);
 
-  p->conn = g_object_ref (G_OBJECT (connection));
+  p->conn = (GDBusConnection*)g_object_ref (G_OBJECT (connection));
 
   /* export the actions */
   if ((id = g_dbus_connection_export_action_group (connection,
